@@ -14,6 +14,7 @@ from __future__ import division
 
 import warnings
 from abc import ABCMeta, abstractmethod
+import sys
 
 import six
 from six.moves import zip
@@ -620,17 +621,17 @@ class TestQuery(unittest.TestCase):
             'space=a+a&amp=a%26a', 'a a=a a&no encoding=sup', 'a+a=a+a',
             'a%20=a+a', 'a%20a=a%20a', 'a+a=a%20a', 'space=a a&amp=a^a',
             'a=a&s=s#s', '+=+', "/?:@-._~!$&'()*+,=/?:@-._~!$'()*+,=",
-            'a=a&c=c%5Ec', '<=>&^="', '%3C=%3E&%5E=%22', '%=%;`=`',
+            'a=a&c=c%5Ec', '<=>&^="', '%3C=%3E&%5E=%22', '%=%&`=`',
             '%25=%25&%60=%60',
             # Only keys, no values.
             'asdfasdf', '/asdf/asdf/sdf', '*******', '!@#(*&@!#(*@!#', 'a&b',
-            'a;b',
+            'a&b',
             # Repeated parameters.
             'a=a&a=a', 'space=a+a&space=b+b',
             # Empty keys and/or values.
             '=', 'a=', 'a=a&a=', '=a&=b',
-            # Semicolon delimiter, like 'a=a;b=b'.
-            'a=a;a=a', 'space=a+a;space=b+b',
+            # Semicolon delimiter is not allowed per default after bpo#42967
+            'a=a&a=a', 'space=a+a&space=b+b',
         ]))
         self.items = (self.itemlists + self.itemdicts + self.itemomdicts +
                       self.itemstrs)
@@ -766,12 +767,10 @@ class TestQuery(unittest.TestCase):
         q = furl.Query('a=&=b')
         assert q.params == {'a': '', '': 'b'} and str(q) == 'a=&=b'
 
-        # ';' is a valid query delimiter.
+        # ';' is no longer a valid query delimiter, though it was prior to furl
+        # v2.1.3. See https://bugs.python.org/issue42967.
         q = furl.Query('=;=')
-        assert q.params.allitems() == [('', ''), ('', '')] and str(q) == '=&='
-        q = furl.Query('a=a;b=b;c=')
-        assert q.params == {
-            'a': 'a', 'b': 'b', 'c': ''} and str(q) == 'a=a&b=b&c='
+        assert q.params.allitems() == [('', ';=')] and str(q) == '=%3B='
 
         # Non-string parameters are coerced to strings in the final
         # query string.
@@ -1580,20 +1579,14 @@ class TestFurl(unittest.TestCase):
         assert str(f.fragment) == ''
         assert f.url == ''
 
-        # Keep in mind that ';' is a query delimiter for both the URL
-        # query and the fragment query, resulting in the str(path),
-        # str(query), and str(fragment) values below.
         url = (
             "sup://example.com/:@-._~!$&'()*+,=;:@-._~!$&'()*+,=:@-._~!$&'()*+"
             ",==?/?:@-._~!$'()*+,;=/?:@-._~!$'()*+,;==#/?:@-._~!$&'()*+,;=")
         pathstr = "/:@-._~!$&'()*+,=;:@-._~!$&'()*+,=:@-._~!$&'()*+,=="
         querystr = (
-            quote_plus("/?:@-._~!$'()* ,") + '&' +
-            '=' + quote_plus("/?:@-._~!$'()* ,") + '&' +
-            '==')
-        fragmentstr = (
-            '/?' + quote_plus(':@-._~!$') + '&' +
-            quote_plus("'()* ,") + '&' + '=')
+            quote_plus("/?:@-._~!$'()* ,;") + '=' +
+            quote_plus("/?:@-._~!$'()* ,;=="))
+        fragmentstr = quote_plus("/?:@-._~!$&'()* ,;=", '/?&=')
         f = furl.furl(url)
         assert f.scheme == 'sup'
         assert f.host == 'example.com'
@@ -2063,9 +2056,13 @@ class TestFurl(unittest.TestCase):
         assert f.url == 'http://pepp.ru/a/b/c#uwantpump?'
 
         # In edge cases (e.g. URLs without an authority/netloc), behave
-        # identically to urllib.parse.urljoin().
+        # identically to urllib.parse.urljoin(), which changed behavior in
+        # Python 3.9.
         f = furl.furl('wss://slrp.com/').join('foo:1')
-        assert f.url == 'wss://slrp.com/foo:1'
+        if sys.version_info[:2] < (3, 9):
+            assert f.url == 'wss://slrp.com/foo:1'
+        else:
+            assert f.url == 'foo:1'
         f = furl.furl('wss://slrp.com/').join('foo:1:rip')
         assert f.url == 'foo:1:rip'
         f = furl.furl('scheme:path').join('foo:blah')
